==> igniteui-react-core-18.0.0.tgz: package/esm5/lib/ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelTemplateWidthRequestedEventArgsDescription } from "./ListPanelTemplateWidthRequestedEventArgsDescription";
/**
 * @hidden
 */
var ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata, _super);
    function ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.b = function (a) {
        if (ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a == null) {
            ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.c(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a);
        }
        if (a.g(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a);
    };
    ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.c = function (a) {
        a.item("DataRow", "Number:int");
        a.item("DataItemRef", "(w:DataItem,wf:DataItem)DataRef");
        a.item("Width", "Number:double");
    };
    ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.d = function (a) {
        ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.b(a);
        a.u("ListPanelTemplateWidthRequestedEventArgs", function () { return new ListPanelTemplateWidthRequestedEventArgsDescription(); });
        a.t("ListPanelTemplateWidthRequestedEventArgs", ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a);
    };
    ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.$t = markType(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata, 'ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata');
    ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata;
}(Base));
export { ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelTemplateWidthRequestedEventArgsDescription } from "./ListPanelTemplateWidthRequestedEventArgsDescription";
/**
 * @hidden
 */
var ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata, _super);
    function ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.b = function (a) {
        if (ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a == null) {
            ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.c(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a);
        }
        if (a.j(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a);
    };
    ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.c = function (a) {
        a.item("DataRow", "Number:int");
        a.item("DataItemRef", "(w:DataItem,wf:DataItem)DataRef");
        a.item("Width", "Number:double");
    };
    ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.d = function (a) {
        ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.b(a);
        a.aa("ListPanelTemplateWidthRequestedEventArgs", function () { return new ListPanelTemplateWidthRequestedEventArgsDescription(); });
        a.z("ListPanelTemplateWidthRequestedEventArgs", ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a);
    };
    ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.$t = markType(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata, 'ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata');
    ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata;
}(Base));
export { ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata };
